import customtkinter as ctk
from tkinter import messagebox
import requests

def login_frame(parent, switch_func, api_url):
    frame = ctk.CTkFrame(parent)

    def login():
        email = entry_email.get()
        password = entry_password.get()

        if not email or not password:
            messagebox.showwarning("Input Error", "Both fields are required!")
            return

        response = requests.post(
            f"{api_url}/auth/login", json={"email": email, "password": password}
        )

        try:
            response_data = response.json()
            if response.status_code == 200:
                access_token = response_data["access_token"]
                messagebox.showinfo("Login Successful", f"Welcome back, {email}!")
                switch_func("create_shop", access_token)
            else:
                messagebox.showerror("Login Failed", response_data.get("detail", "Invalid credentials"))
        except requests.exceptions.JSONDecodeError:
            messagebox.showerror("Login Failed", "Server returned an invalid response.")

    ctk.CTkLabel(frame, text="Login", font=("Helvetica", 18, "bold")).pack(pady=10)

    ctk.CTkLabel(frame, text="Email:").pack(pady=5)
    entry_email = ctk.CTkEntry(frame)
    entry_email.pack(pady=5)

    ctk.CTkLabel(frame, text="Password:").pack(pady=5)
    entry_password = ctk.CTkEntry(frame, show="*")
    entry_password.pack(pady=5)

    ctk.CTkButton(frame, text="Login", command=login).pack(pady=15)

    ctk.CTkButton(
        frame,
        text="Don't have an account? Register",
        command=lambda: switch_func("register"),
    ).pack()

    return frame
