import customtkinter as ctk
from components.auth.login import login_frame
from components.auth.register import register_frame
from components.shop.create_shop import create_shop_frame
from components.shop.view_shop import view_shop_frame
from components.product.create_product import product_frame
from components.admin.category import category_frame

# Backend API URL
API_URL = "http://127.0.0.1:8000"

# Global variable to store the access token
access_token = None

# Function to switch between frames
def switch_frame(frame_name, token=None):
    global access_token
    if token:
        access_token = token

    frames.get(frame_name, login).tkraise()  # Default to login if frame_name is invalid

# Create main window
ctk.set_appearance_mode("dark")  # Light, Dark, or System
ctk.set_default_color_theme("blue")

root = ctk.CTk()
root.title("Shopping App")
root.geometry("900x800")

# Create Frames inside the main window
login = login_frame(root, switch_frame, API_URL)
register = register_frame(root, switch_frame, API_URL)
create_shop = create_shop_frame(root, switch_frame, API_URL, access_token)
view_shop = view_shop_frame(root, switch_frame, API_URL, access_token)
product = product_frame(root, switch_frame, API_URL, access_token)
category = category_frame(root, switch_frame, API_URL, access_token)

# Store frames in a dictionary for easier management
frames = {
    "login": login,
    "register": register,
    "create_shop": create_shop,
    "create_product": product,
    "category": category,
    "view_shop": view_shop
}

# Place all frames responsively
for frame in frames.values():
    frame.place(relx=0, rely=0.2, relwidth=1, relheight=0.8)

# Show the login frame first
switch_frame("view_shop")

root.mainloop()
